==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/BackendCredentialsContractArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.BackendCredentialsContractArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Details of the Credentials used to connect to Backend.
 * @property authorization Authorization header authentication
 * @property certificate List of Client Certificate Thumbprints. Will be ignored if certificatesIds are provided.
 * @property certificateIds List of Client Certificate Ids.
 * @property header Header Parameter description.
 * @property query Query Parameter description.
 */
public data class BackendCredentialsContractArgs(
    public val authorization: Output<BackendAuthorizationHeaderCredentialsArgs>? = null,
    public val certificate: Output<List<String>>? = null,
    public val certificateIds: Output<List<String>>? = null,
    public val `header`: Output<Map<String, List<String>>>? = null,
    public val query: Output<Map<String, List<String>>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.BackendCredentialsContractArgs> {
    override fun toJava(): com.pulumi.azurenative.apimanagement.inputs.BackendCredentialsContractArgs =
        com.pulumi.azurenative.apimanagement.inputs.BackendCredentialsContractArgs.builder()
            .authorization(authorization?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .certificate(certificate?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .certificateIds(certificateIds?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .`header`(
                `header`?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value.map({ args0 -> args0 }))
                    }).toMap()
                }),
            )
            .query(
                query?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(
                            args0.value.map({ args0 ->
                                args0
                            }),
                        )
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [BackendCredentialsContractArgs].
 */
@PulumiTagMarker
public class BackendCredentialsContractArgsBuilder internal constructor() {
    private var authorization: Output<BackendAuthorizationHeaderCredentialsArgs>? = null

    private var certificate: Output<List<String>>? = null

    private var certificateIds: Output<List<String>>? = null

    private var `header`: Output<Map<String, List<String>>>? = null

    private var query: Output<Map<String, List<String>>>? = null

    /**
     * @param value Authorization header authentication
     */
    @JvmName("smvrnpyrhastccii")
    public suspend fun authorization(`value`: Output<BackendAuthorizationHeaderCredentialsArgs>) {
        this.authorization = value
    }

    /**
     * @param value List of Client Certificate Thumbprints. Will be ignored if certificatesIds are provided.
     */
    @JvmName("npiiijfywqllmvxg")
    public suspend fun certificate(`value`: Output<List<String>>) {
        this.certificate = value
    }

    @JvmName("djpawfmeaxhwivca")
    public suspend fun certificate(vararg values: Output<String>) {
        this.certificate = Output.all(values.asList())
    }

    /**
     * @param values List of Client Certificate Thumbprints. Will be ignored if certificatesIds are provided.
     */
    @JvmName("bvjabjhhdnnlkguy")
    public suspend fun certificate(values: List<Output<String>>) {
        this.certificate = Output.all(values)
    }

    /**
     * @param value List of Client Certificate Ids.
     */
    @JvmName("iftnfuyjewmmikqv")
    public suspend fun certificateIds(`value`: Output<List<String>>) {
        this.certificateIds = value
    }

    @JvmName("vqgyawosetwhmmgn")
    public suspend fun certificateIds(vararg values: Output<String>) {
        this.certificateIds = Output.all(values.asList())
    }

    /**
     * @param values List of Client Certificate Ids.
     */
    @JvmName("ryolleybcduaxmak")
    public suspend fun certificateIds(values: List<Output<String>>) {
        this.certificateIds = Output.all(values)
    }

    /**
     * @param value Header Parameter description.
     */
    @JvmName("vacjyqdvjfcaalai")
    public suspend fun `header`(`value`: Output<Map<String, List<String>>>) {
        this.`header` = value
    }

    /**
     * @param value Query Parameter description.
     */
    @JvmName("rudlplqggaellpek")
    public suspend fun query(`value`: Output<Map<String, List<String>>>) {
        this.query = value
    }

    /**
     * @param value Authorization header authentication
     */
    @JvmName("lrwssuhdokksrmtl")
    public suspend fun authorization(`value`: BackendAuthorizationHeaderCredentialsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authorization = mapped
    }

    /**
     * @param argument Authorization header authentication
     */
    @JvmName("xawbfyenxnygygkc")
    public suspend
    fun authorization(argument: suspend BackendAuthorizationHeaderCredentialsArgsBuilder.() -> Unit) {
        val toBeMapped = BackendAuthorizationHeaderCredentialsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.authorization = mapped
    }

    /**
     * @param value List of Client Certificate Thumbprints. Will be ignored if certificatesIds are provided.
     */
    @JvmName("qfbgrtfkrverpaps")
    public suspend fun certificate(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.certificate = mapped
    }

    /**
     * @param values List of Client Certificate Thumbprints. Will be ignored if certificatesIds are provided.
     */
    @JvmName("nxngnjkxbnpyohpy")
    public suspend fun certificate(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.certificate = mapped
    }

    /**
     * @param value List of Client Certificate Ids.
     */
    @JvmName("nttwqagwmelvwciq")
    public suspend fun certificateIds(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.certificateIds = mapped
    }

    /**
     * @param values List of Client Certificate Ids.
     */
    @JvmName("mdorhaxihwujxfxv")
    public suspend fun certificateIds(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.certificateIds = mapped
    }

    /**
     * @param value Header Parameter description.
     */
    @JvmName("ksvbvochfeefnvew")
    public suspend fun `header`(`value`: Map<String, List<String>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`header` = mapped
    }

    /**
     * @param values Header Parameter description.
     */
    @JvmName("gxjagxbfqjxkcamm")
    public fun `header`(vararg values: Pair<String, List<String>>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`header` = mapped
    }

    /**
     * @param value Query Parameter description.
     */
    @JvmName("utjocqhdwtnnnwhh")
    public suspend fun query(`value`: Map<String, List<String>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.query = mapped
    }

    /**
     * @param values Query Parameter description.
     */
    @JvmName("tumnvgeykisvkmkf")
    public fun query(vararg values: Pair<String, List<String>>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.query = mapped
    }

    internal fun build(): BackendCredentialsContractArgs = BackendCredentialsContractArgs(
        authorization = authorization,
        certificate = certificate,
        certificateIds = certificateIds,
        `header` = `header`,
        query = query,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/BackendCredentialsContractArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.BackendCredentialsContractArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Details of the Credentials used to connect to Backend.
 * @property authorization Authorization header authentication
 * @property certificate List of Client Certificate Thumbprints. Will be ignored if certificatesIds are provided.
 * @property certificateIds List of Client Certificate Ids.
 * @property header Header Parameter description.
 * @property query Query Parameter description.
 */
public data class BackendCredentialsContractArgs(
    public val authorization: Output<BackendAuthorizationHeaderCredentialsArgs>? = null,
    public val certificate: Output<List<String>>? = null,
    public val certificateIds: Output<List<String>>? = null,
    public val `header`: Output<Map<String, List<String>>>? = null,
    public val query: Output<Map<String, List<String>>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.BackendCredentialsContractArgs> {
    override fun toJava(): com.pulumi.azurenative.apimanagement.inputs.BackendCredentialsContractArgs =
        com.pulumi.azurenative.apimanagement.inputs.BackendCredentialsContractArgs.builder()
            .authorization(authorization?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .certificate(certificate?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .certificateIds(certificateIds?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .`header`(
                `header`?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value.map({ args0 -> args0 }))
                    }).toMap()
                }),
            )
            .query(
                query?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(
                            args0.value.map({ args0 ->
                                args0
                            }),
                        )
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [BackendCredentialsContractArgs].
 */
@PulumiTagMarker
public class BackendCredentialsContractArgsBuilder internal constructor() {
    private var authorization: Output<BackendAuthorizationHeaderCredentialsArgs>? = null

    private var certificate: Output<List<String>>? = null

    private var certificateIds: Output<List<String>>? = null

    private var `header`: Output<Map<String, List<String>>>? = null

    private var query: Output<Map<String, List<String>>>? = null

    /**
     * @param value Authorization header authentication
     */
    @JvmName("rbnmlfmwngkycdna")
    public suspend fun authorization(`value`: Output<BackendAuthorizationHeaderCredentialsArgs>) {
        this.authorization = value
    }

    /**
     * @param value List of Client Certificate Thumbprints. Will be ignored if certificatesIds are provided.
     */
    @JvmName("irmbncugnnbljddg")
    public suspend fun certificate(`value`: Output<List<String>>) {
        this.certificate = value
    }

    @JvmName("axyohixnbawjitqq")
    public suspend fun certificate(vararg values: Output<String>) {
        this.certificate = Output.all(values.asList())
    }

    /**
     * @param values List of Client Certificate Thumbprints. Will be ignored if certificatesIds are provided.
     */
    @JvmName("yejjbmaussyucsyl")
    public suspend fun certificate(values: List<Output<String>>) {
        this.certificate = Output.all(values)
    }

    /**
     * @param value List of Client Certificate Ids.
     */
    @JvmName("xagqrrqbnyvaomek")
    public suspend fun certificateIds(`value`: Output<List<String>>) {
        this.certificateIds = value
    }

    @JvmName("uytwnkuyllvcyyvm")
    public suspend fun certificateIds(vararg values: Output<String>) {
        this.certificateIds = Output.all(values.asList())
    }

    /**
     * @param values List of Client Certificate Ids.
     */
    @JvmName("skxkhyihscfkbsks")
    public suspend fun certificateIds(values: List<Output<String>>) {
        this.certificateIds = Output.all(values)
    }

    /**
     * @param value Header Parameter description.
     */
    @JvmName("aenkboimngfhkowv")
    public suspend fun `header`(`value`: Output<Map<String, List<String>>>) {
        this.`header` = value
    }

    /**
     * @param value Query Parameter description.
     */
    @JvmName("mmgatwiiuhdyypxo")
    public suspend fun query(`value`: Output<Map<String, List<String>>>) {
        this.query = value
    }

    /**
     * @param value Authorization header authentication
     */
    @JvmName("ohuvskxkgitruduk")
    public suspend fun authorization(`value`: BackendAuthorizationHeaderCredentialsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authorization = mapped
    }

    /**
     * @param argument Authorization header authentication
     */
    @JvmName("iclowqgcylrddmci")
    public suspend
    fun authorization(argument: suspend BackendAuthorizationHeaderCredentialsArgsBuilder.() -> Unit) {
        val toBeMapped = BackendAuthorizationHeaderCredentialsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.authorization = mapped
    }

    /**
     * @param value List of Client Certificate Thumbprints. Will be ignored if certificatesIds are provided.
     */
    @JvmName("tichrrrmurkrxapm")
    public suspend fun certificate(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.certificate = mapped
    }

    /**
     * @param values List of Client Certificate Thumbprints. Will be ignored if certificatesIds are provided.
     */
    @JvmName("qjowwwpjhhwkpnta")
    public suspend fun certificate(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.certificate = mapped
    }

    /**
     * @param value List of Client Certificate Ids.
     */
    @JvmName("toghkcxvkilijqom")
    public suspend fun certificateIds(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.certificateIds = mapped
    }

    /**
     * @param values List of Client Certificate Ids.
     */
    @JvmName("uunqkuruvkkalucd")
    public suspend fun certificateIds(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.certificateIds = mapped
    }

    /**
     * @param value Header Parameter description.
     */
    @JvmName("krblagnwoehsttxq")
    public suspend fun `header`(`value`: Map<String, List<String>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`header` = mapped
    }

    /**
     * @param values Header Parameter description.
     */
    @JvmName("qfgcdbyhkdmuukjh")
    public fun `header`(vararg values: Pair<String, List<String>>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`header` = mapped
    }

    /**
     * @param value Query Parameter description.
     */
    @JvmName("kcyrlowmmllyenxy")
    public suspend fun query(`value`: Map<String, List<String>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.query = mapped
    }

    /**
     * @param values Query Parameter description.
     */
    @JvmName("lmjlbhgqcgrgtocp")
    public fun query(vararg values: Pair<String, List<String>>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.query = mapped
    }

    internal fun build(): BackendCredentialsContractArgs = BackendCredentialsContractArgs(
        authorization = authorization,
        certificate = certificate,
        certificateIds = certificateIds,
        `header` = `header`,
        query = query,
    )
}
